==> chromium-8.0.552.40.tar.bz2: chromium-8.0.552.40/chrome/installer/util/google_update_constants.cc <==
// Copyright (c) 2006-2008 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/installer/util/google_update_constants.h"

namespace google_update {

const wchar_t kGearsUpgradeCode[] = L"{D92DBAED-3E3E-4530-B30D-072D16C7DDD0}";
const wchar_t kChromeUpgradeCode[] = L"{8A69D345-D564-463C-AFF1-A69D9E530F96}";

const wchar_t kRegPathClients[] = L"Software\\Google\\Update\\Clients";
const wchar_t kRegPathClientState[] = L"Software\\Google\\Update\\ClientState";
const wchar_t kRegPathClientStateMedium[]
    = L"Software\\Google\\Update\\ClientStateMedium";

const wchar_t kRegApField[] = L"ap";
const wchar_t kRegBrowserField[] = L"browser";
const wchar_t kRegClientField[] = L"client";
const wchar_t kRegDidRunField[] = L"dr";
const wchar_t kRegLangField[] = L"lang";
const wchar_t kRegLastCheckedField[] = L"LastChecked";
const wchar_t kRegMetricsId[] = L"metricsid";
const wchar_t kRegMSIField[] = L"msi";
const wchar_t kRegNameField[] = L"name";
const wchar_t kRegOopcrashesField[] = L"oopcrashes";
const wchar_t kRegOldVersionField[] = L"opv";
const wchar_t kRegRenameCmdField[] = L"cmd";
const wchar_t kRegRLZBrandField[] = L"brand";
const wchar_t kRegUsageStatsField[] = L"usagestats";
const wchar_t kRegVersionField[] = L"pv";
const wchar_t kRegReferralField[] = L"referral";
const wchar_t kRegEULAAceptedField[] = L"eulaaccepted";
const wchar_t kRegLastRunTimeField[] = L"lastrun";

}  // namespace google_update

==> chromium-10.0.648.204.tar.bz2: chromium-10.0.648.204/chrome/installer/util/google_update_constants.cc <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/installer/util/google_update_constants.h"

namespace google_update {

const wchar_t kGearsUpgradeCode[] = L"{D92DBAED-3E3E-4530-B30D-072D16C7DDD0}";
const wchar_t kChromeUpgradeCode[] = L"{8A69D345-D564-463C-AFF1-A69D9E530F96}";

const wchar_t kRegPathClients[] = L"Software\\Google\\Update\\Clients";
const wchar_t kRegPathClientState[] = L"Software\\Google\\Update\\ClientState";
const wchar_t kRegPathClientStateMedium[]
    = L"Software\\Google\\Update\\ClientStateMedium";

const wchar_t kRegApField[] = L"ap";
const wchar_t kRegBrowserField[] = L"browser";
const wchar_t kRegClientField[] = L"client";
const wchar_t kRegDidRunField[] = L"dr";
const wchar_t kRegLangField[] = L"lang";
const wchar_t kRegLastCheckedField[] = L"LastChecked";
const wchar_t kRegMetricsId[] = L"metricsid";
const wchar_t kRegMSIField[] = L"msi";
const wchar_t kRegNameField[] = L"name";
const wchar_t kRegOopcrashesField[] = L"oopcrashes";
const wchar_t kRegOldVersionField[] = L"opv";
const wchar_t kRegRenameCmdField[] = L"cmd";
const wchar_t kRegRLZBrandField[] = L"brand";
const wchar_t kRegUsageStatsField[] = L"usagestats";
const wchar_t kRegVersionField[] = L"pv";
const wchar_t kRegReferralField[] = L"referral";
const wchar_t kRegEULAAceptedField[] = L"eulaaccepted";
const wchar_t kRegLastRunTimeField[] = L"lastrun";
const wchar_t kRegCFTempOptOutCmdField[] = L"CFTempOptOutCmd";
const wchar_t kRegCFEndTempOptOutCmdField[] = L"CFEndTempOptOutCmd";
const wchar_t kRegCFOptOutCmdField[] = L"CFOptOutCmd";
const wchar_t kRegCFOptInCmdField[] = L"CFOptInCmd";

}  // namespace google_update
